@@ -96,7 +96,7 @@ microtable <- R6Class(classname = "microtable",
 		#' This operation will remove any line of the \code{microtable$tax_table} containing any the word in taxa parameter regardless of word case.
 		#'
 		#' @param taxa default \code{c("mitochondria", "chloroplast")}; filter mitochondria and chloroplast, or others as needed.
-		#' @return None
+		#' @return updated microtable object
 		#' @examples 
 		#' m1$filter_pollution(taxa = c("mitochondria", "chloroplast"))
 		filter_pollution = function(taxa = c("mitochondria", "chloroplast")){
@@ -115,7 +115,7 @@ microtable <- R6Class(classname = "microtable",
 			invisible(self)
 		},
 		#' @description
-		#' Filter the feature with low abundance and/or low occurrence frequency.
+		#' Filter the features with low abundance and/or low occurrence frequency for \code{otu_table} or \code{taxa_abund} list.
 		#'
 		#' @param rel_abund default 0; the relative abundance threshold, such as 0.0001.
 		#' @param freq default 1; the occurrence frequency threshold. 
@@ -123,61 +123,90 @@ microtable <- R6Class(classname = "microtable",
 		#' 	 A number smaller than 1 is also allowable. 
 		#' 	 For instance, the number 0.1 represents filtering the feature that occurs in less than 10\% samples.
 		#' @param include_lowest default TRUE; whether include the feature with the threshold.
-		#' @return None
+		#' @param for_taxa_abund default FALSE; whether apply this function to \code{taxa_abund} list. FALSE means using this function for \code{otu_table}
+		#' @return updated microtable object
 		#' @examples
 		#' \donttest{
 		#' d1 <- clone(m1)
 		#' d1$filter_taxa(rel_abund = 0.0001, freq = 0.2)
 		#' }
-		filter_taxa = function(rel_abund = 0, freq = 1, include_lowest = TRUE){
-			raw_otu_table <- self$otu_table
-			if(rel_abund != 0){
-				if(rel_abund >= 1){
-					stop("rel_abund must be smaller than 1!")
+		filter_taxa = function(rel_abund = 0, freq = 1, include_lowest = TRUE, for_taxa_abund = FALSE){
+			raw_data <- list()
+			if(for_taxa_abund){
+				if(is.null(self$taxa_abund)){
+					message("taxa_abund list is NULL. Automatically calculate the relative abundance using cal_abund function ...")
+					self$cal_abund()
 				}
-				taxa_raw_abund <- self$taxa_sums()
-				taxa_rel_abund <- taxa_raw_abund/sum(taxa_raw_abund)
-				if(include_lowest){
-					abund_names <- taxa_rel_abund[taxa_rel_abund < rel_abund] %>% names
+				raw_data <- self$taxa_abund
+				message("Filter features for tables in taxa_abund list in the object ...")
+			}else{
+				raw_data[["otu_table"]] <- self$otu_table
+				message("Filter features for otu_table in the object ...")
+			}
+			
+			for(i in names(raw_data)){
+				input_data <- raw_data[[i]]
+				
+				if(rel_abund != 0){
+					if(rel_abund >= 1){
+						stop("The parameter rel_abund must be smaller than 1!")
+					}
+					if(for_taxa_abund){
+						taxa_rel_abund <- apply(input_data, 1, mean)
+					}else{
+						taxa_raw_abund <- self$taxa_sums()
+						taxa_rel_abund <- taxa_raw_abund/sum(taxa_raw_abund)
+					}
+
+					if(include_lowest){
+						abund_names <- taxa_rel_abund[taxa_rel_abund < rel_abund] %>% names
+					}else{
+						abund_names <- taxa_rel_abund[taxa_rel_abund <= rel_abund] %>% names
+					}
+					if(length(abund_names) == nrow(input_data)){
+						stop("No feature remained! Please check the rel_abund parameter!")
+					}
+					message(length(abund_names), " features filtered based on the abundance for ", i, " ...")
 				}else{
-					abund_names <- taxa_rel_abund[taxa_rel_abund <= rel_abund] %>% names
+					abund_names <- c()
 				}
-				if(length(abund_names) == nrow(raw_otu_table)){
-					stop("No feature remained! Please check the rel_abund parameter!")
-				}
-				message(length(abund_names), " features filtered based on the abundance ...")
-			}else{
-				abund_names <- c()
-			}
-			if(freq != 0){
-				if(freq < 1){
-					message("freq smaller than 1; first convert it to an integer ...")
-					freq <- round(ncol(raw_otu_table) * freq)
-					message("Use converted freq integer: ", freq, " for the following filtering ...")
-				}
-				taxa_occur_num <- apply(raw_otu_table, 1, function(x){sum(x != 0)})
-				if(include_lowest){
-					freq_names <- taxa_occur_num[taxa_occur_num < freq] %>% names
+				if(freq != 0){
+					if(freq < 1){
+						message("freq smaller than 1; first convert it to an integer ...")
+						freq <- round(ncol(input_data) * freq)
+						message("Use converted freq integer: ", freq, " for the following filtering ...")
+					}
+					taxa_occur_num <- apply(input_data, 1, function(x){sum(x != 0)})
+					if(include_lowest){
+						freq_names <- taxa_occur_num[taxa_occur_num < freq] %>% names
+					}else{
+						freq_names <- taxa_occur_num[taxa_occur_num <= freq] %>% names
+					}
+					if(length(freq_names) == nrow(input_data)){
+						stop("No feature remained! Please check the freq parameter!")
+					}
+					message(length(freq_names), " features filtered based on the occurrence for ", i, " ...")
 				}else{
-					freq_names <- taxa_occur_num[taxa_occur_num <= freq] %>% names
+					freq_names <- c()
 				}
-				if(length(freq_names) == nrow(raw_otu_table)){
-					stop("No feature remained! Please check the freq parameter!")
+				filter_names <- c(abund_names, freq_names) %>% unique
+				if(length(filter_names) == 0){
+					new_table <- input_data
+				}else{
+					if(length(filter_names) == nrow(input_data)){
+						stop("All features are filtered! Please adjust the parameters")
+					}
+					new_table <- input_data[! rownames(input_data) %in% filter_names, , drop = FALSE]
 				}
-				message(length(freq_names), " features filtered based on the occurrence...")
-			}else{
-				freq_names <- c()
+				raw_data[[i]] <- new_table
 			}
-			filter_names <- c(abund_names, freq_names) %>% unique
-			if(length(filter_names) == 0){
-				new_table <- raw_otu_table
+			
+			if(for_taxa_abund){
+				self$taxa_abund <- raw_data
 			}else{
-				if(length(filter_names) == nrow(raw_otu_table)){
-					stop("All features are filtered! Please adjust the parameters")
-				}
-				new_table <- raw_otu_table[! rownames(raw_otu_table) %in% filter_names, , drop = FALSE]
+				self$otu_table <- raw_data[["otu_table"]]
 			}
-			self$otu_table <- new_table
+
 			self$tidy_dataset()
 			invisible(self)
 		},
@@ -189,7 +218,7 @@ microtable <- R6Class(classname = "microtable",
 		#' @param sample.size default NULL; libray size. If not provided, use the minimum number across all samples. 
 		#'    For "SRS" method, this parameter is passed to \code{Cmin} parameter of \code{SRS} function of SRS package.
 		#' @param ... parameters pass to \code{norm} function of \code{\link{trans_norm}} class.
-		#' @return None; rarefied dataset.
+		#' @return rarefied microtable object.
 		#' @examples
 		#' \donttest{
 		#' m1$rarefy_samples(sample.size = min(m1$sample_sums()))
@@ -217,7 +246,8 @@ microtable <- R6Class(classname = "microtable",
 		#' m1$tidy_dataset(main_data = TRUE)
 		tidy_dataset = function(main_data = FALSE){
 			self <- private$tidy_samples(self)
-			self$otu_table %<>% {.[apply(., 1, sum) > 0, , drop = FALSE]}
+			# check again the abundance for the case that sample filtering leads to 0 abundance of some features
+			self$otu_table <- private$check_abund_table(self$otu_table)
 			taxa_list <- list(rownames(self$otu_table), rownames(self$tax_table), self$phylo_tree$tip.label) %>% 
 				.[!unlist(lapply(., is.null))]
 			taxa_names <- Reduce(intersect, taxa_list)
@@ -268,7 +298,7 @@ microtable <- R6Class(classname = "microtable",
 		#' 	 for the taxonomic abundance calculation and biomarker idenfification.
 		#'
 		#' @param use_name default "OTU"; The column name used in the \code{tax_table}.
-		#' @return NULL, a new tax_table stored in the object.
+		#' @return new tax_table stored in the object.
 		#' @examples
 		#' \donttest{
 		#' m1$add_rownames2taxonomy()
@@ -339,7 +369,7 @@ microtable <- R6Class(classname = "microtable",
 		#' Rename the features, including the rownames of \code{otu_table}, rownames of \code{tax_table}, tip labels of \code{phylo_tree} and \code{rep_fasta}.
 		#'
 		#' @param newname_prefix default "ASV_"; the prefix of new names; new names will be newname_prefix + numbers according to the rownames order of \code{otu_table}.
-		#' @return None; renamed dataset.
+		#' @return renamed microtable object
 		#' @examples
 		#' \donttest{
 		#' m1$rename_taxa()
@@ -405,7 +435,7 @@ microtable <- R6Class(classname = "microtable",
 		#' Merge taxa according to specific taxonomic rank to generate a new \code{microtable}.
 		#'
 		#' @param taxa default "Genus"; the specific rank in \code{tax_table}.
-		#' @return a new merged \code{microtable} object.
+		#' @return merged \code{microtable} object.
 		#' @examples
 		#' \donttest{
 		#' m1$merge_taxa(taxa = "Genus")
@@ -861,15 +891,17 @@ microtable <- R6Class(classname = "microtable",
 			if(!all(sapply(otu_table, is.numeric))){
 				stop("Some columns in otu_table are not numeric class! Please check the input data!")
 			}
-			if(any(apply(otu_table, 1, sum) == 0)){
-				remove_num <- sum(apply(otu_table, 1, sum) == 0)
+			if(any(apply(otu_table, 1, function(x){all(x == 0)}))){
+				all_zero <- apply(otu_table, 1, function(x){all(x == 0)})
+				remove_num <- sum(all_zero)
 				message(remove_num, " taxa with 0 abundance are removed from the otu_table ...")
-				otu_table %<>% .[apply(., 1, sum) > 0, , drop = FALSE]
+				otu_table %<>% .[! all_zero, , drop = FALSE]
 			}
-			if(any(apply(otu_table, 2, sum) == 0)){
-				remove_num <- sum(apply(otu_table, 2, sum) == 0)
+			if(any(apply(otu_table, 2, function(x){all(x == 0)}))){
+				all_zero <- apply(otu_table, 2, function(x){all(x == 0)})
+				remove_num <- sum(all_zero)
 				message(remove_num, " samples with 0 abundance are removed from the otu_table ...")
-				otu_table %<>% .[, apply(., 2, sum) > 0, drop = FALSE]
+				otu_table %<>% .[, ! all_zero, drop = FALSE]
 			}
 			if(ncol(otu_table) == 0){
 				stop("No available sample! Please check the data!")
